package com.caimei.controller;

import com.caimei.config.FastDfsClient;
import com.caimei.mapper.FileMapper;
import com.caimei.model.po.FilePo;
import com.caimei.service.UploadService;
import com.caimei.utils.OSSUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.codec.digest.DigestUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.util.HashMap;
import java.util.Map;
import java.util.UUID;

/**
 * @author Aslee
 * @date 2021/5/14
 */
@Api(tags = "上传API")
@Slf4j
@RestController
@RequiredArgsConstructor
@RequestMapping("/upload")
public class UploadApi {
    private static final Logger logger = LoggerFactory.getLogger(UploadApi.class);
    @Value("${caimei.imageDomain}")
    private String imageDomain;
    private final UploadService uploadService;

    /**
     * 上传图片
     */
    @ApiOperation("上传图片")
    @ApiImplicitParam(name = "file", value = "图片", required = true)
    @PostMapping("/image")
    public Map<String, Object> uploadImage(MultipartFile file) throws IOException {
        Map<String, Object> map = new HashMap<>(2);
        String saveFile;
        if (file != null ) {
            // 保存文件
            saveFile = uploadService.saveFile(file);
            saveFile = imageDomain + "/" + saveFile;
            map.put("data", saveFile);
            map.put("msg", "上传成功");
            logger.info(">>>>>>>>>>>>>>>>图片上传成功:" + saveFile);
        } else {
            map.put("msg", "上传失败");
            logger.info(">>>>>>>>>>>>>>>>图片上传失败:");
        }
        return map;
    }



    @ApiOperation("上传文件")
    @ApiImplicitParam(name = "file", value = "文件", required = true)
    @PostMapping("/file")
    public Map<String, Object> uploadFile(MultipartFile file) throws IOException {
        Map<String, Object> map = new HashMap<>(2);
        String fileAllName = file.getOriginalFilename();
        String fileType = fileAllName.substring(fileAllName.lastIndexOf(".") + 1);
        String fileName = file.getResource().getFilename();
        String uuid = UUID.randomUUID().toString().replaceAll("-", "");
        String filePath = uuid + "." + fileType;
        String contentType = OSSUtils.getContentType(fileAllName);
        log.info(">>>>>>>>>>>>>上传文件");
        //保存本地
        File uploadFile = OSSUtils.ossUpload(file);
        //判断文件的唯一性,转换成16进制md5值
        String md5Hex = DigestUtils.md5Hex(new FileInputStream(uploadFile));
        //将文件上传oss
        String url = OSSUtils.ossUpload(filePath, uploadFile, contentType);
        if (StringUtils.isNotEmpty(url)) {
            map.put("fileUrl", url);
            map.put("msg", "上传成功");
            logger.info(">>>>>>>>>>>>>>>>文件上传成功:" + url);
        } else {
            map.put("msg", "上传失败");
            logger.info(">>>>>>>>>>>>>>>>文件上传失败:");
        }
        return map;
    }

}
