package com.caimei.service.impl;

import com.caimei.mapper.FileMapper;
import com.caimei.model.ResponseJson;
import com.caimei.model.po.FilePo;
import com.caimei.model.vo.FileListVo;
import com.caimei.model.vo.WxFileListVo;
import com.caimei.model.vo.WxVideoListVo;
import com.caimei.service.FileService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;

/**
 * Description
 *
 * @author : Aslee
 * @date : 2021/7/9
 */
@Slf4j
@Service
public class FileServiceImpl implements FileService {

    @Resource
    private FileMapper fileMapper;

    @Value("${aliyunConfig.accessKeyId}")
    private String accessKeyId;

    @Value("${aliyunConfig.accessKeySecret}")
    private String accessKeySecret;

    @Value("${aliyunConfig.bucketName}")
    private String bucketName;

    @Value("${aliyunConfig.endpoint}")
    private String endpoint;

    @Value("${spring.profiles.active}")
    private String active;

    @Override
    public ResponseJson<PageInfo<FileListVo>> getFileList(Integer listType, Integer authUserId, String fileTitle, Integer auditStatus, Integer status, Integer pageNum, Integer pageSize) {
        if (null == authUserId) {
            return ResponseJson.error("参数异常，请输入供应商用户id", null);
        }
        listType = null == listType ? 1 : listType;
        PageHelper.startPage(pageNum, pageSize);
        List<FileListVo> fileList = fileMapper.getFileList(listType, authUserId, fileTitle, auditStatus, status);
        PageInfo<FileListVo> pageData = new PageInfo<>(fileList);
        return ResponseJson.success(pageData);
    }

    @Override
    public ResponseJson saveFile(Integer fileId, Integer authUserId, String fileTitle, String fileUrl) {
        if (null == fileId && null == authUserId) {
            return ResponseJson.error("参数异常，请输入供应商用户id");
        }
        if (StringUtils.isEmpty(fileTitle)) {
            return ResponseJson.error("参数异常，请输入文件标题");
        }
        if (null == fileUrl) {
            return ResponseJson.error("参数异常，请上传文件");
        }
        /*
            组装文件数据
        */
        FilePo dataFile = new FilePo();
        if (null != fileId) {
            /*
                更新文件
             */
            dataFile.setId(fileId);
            dataFile.setTitle(fileTitle);
            dataFile.setUrl(fileUrl);
            // 上线状态默认为“待上线”,审核状态为“待审核”
            dataFile.setStatus(2);
            dataFile.setAuditStatus(2);
            fileMapper.updateFileSelective(dataFile);
        } else {
                /*
                    新增文件
                 */
            dataFile.setAuthUserId(authUserId);
            dataFile.setTitle(fileTitle);
            dataFile.setUrl(fileUrl);
            dataFile.setCreateTime(new Date());
            // 上线状态默认为“待上线”,审核状态为“待审核”
            dataFile.setStatus(2);
            dataFile.setAuditStatus(2);
            fileMapper.insertFile(dataFile);
        }
        return ResponseJson.success("保存文件成功");
    }

    @Override
    public ResponseJson updateFileStatus(Integer fileId, Integer status) {
        if (null == fileId) {
            return ResponseJson.error("请输入文件id");
        }
        if (null == status) {
            return ResponseJson.error("请输入要更新的状态值");
        }
        fileMapper.updateFileStatusByFileId(fileId, status);
        if (0 == status) {
            return ResponseJson.success("下线文件成功");
        } else {
            return ResponseJson.success("上线文件成功");
        }
    }

    @Override
    public ResponseJson deleteFile(Integer fileId) {
        if (null == fileId) {
            return ResponseJson.error("参数异常，请输入文件id");
        }
        // 删除文件
        fileMapper.deleteFileByFileId(fileId);
        return ResponseJson.success("删除文件成功");
    }

    @Override
    public ResponseJson auditFile(Integer fileId, Integer auditStatus, String invalidReason, Integer auditBy) {
        if (null == fileId) {
            return ResponseJson.error("请输入文件id");
        }
        if (null == auditStatus) {
            return ResponseJson.error("请输入审核结果");
        }
        if (0 == auditStatus && StringUtils.isEmpty(invalidReason)) {
            return ResponseJson.error("请输入审核不通过的原因");
        }
        if (null == auditBy) {
            return ResponseJson.error("请输入审核人用户id");
        }
        Date auditTime = new Date();
        // 授权状态更新
        Integer status = null;
        if (0 == auditStatus) {
            // 审核不通过，下线文件
            status = 0;
        } else {
            // 审核通过，上线文件
            status = 1;
        }
        fileMapper.updateFileAuditStatus(fileId, status, auditStatus, invalidReason, auditBy, auditTime);
        return ResponseJson.success("审核文件成功");
    }

    @Override
    public ResponseJson<PageInfo<WxFileListVo>> getWxFileList(Integer authUserId, String fileTitle, Integer pageNum, Integer pageSize) {
        if (null == authUserId) {
            return ResponseJson.error("参数异常，供应商用户id不能为空", null);
        }
        PageHelper.startPage(pageNum, pageSize);
        List<WxFileListVo> fileList = fileMapper.getWxFileList(authUserId, fileTitle);
        PageInfo<WxFileListVo> pageData = new PageInfo<>(fileList);
        return ResponseJson.success(pageData);
    }
}
